==> core-react-0.8.0.tgz: package/es/Select/Option/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import TextOverflow from '../../TextOverflow';
import Icon from '../../Icon';


var Option = function Option(props) {
  var _cx;

  var children = props.children,
      className = props.className,
      data = props.data,
      value = props.value,
      selected = props.selected,
      active = props.active,
      other = _objectWithoutProperties(props, ["children", "className", "data", "value", "selected", "active"]);

  var classNames = cx("".concat("waui", "-select__option"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-select__option_active"), active), _defineProperty(_cx, "".concat("waui", "-select__option_selected"), selected), _cx), className);
  return React.createElement("li", _extends({
    className: classNames
  }, other), React.createElement(TextOverflow, null, React.createElement("div", null, children)), selected && React.createElement(Icon, {
    type: "check",
    className: "".concat("waui", "-select__option-icon_selected")
  }));
};

Option.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  data: PropTypes.object,

  /** 值，与 Select value 对应，数据类型也要一致 */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  selected: PropTypes.bool,
  active: PropTypes.bool
};
export default Option;

==> core-react-0.8.2.tgz: package/es/Select/Option/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import TextOverflow from '../../TextOverflow';
import Icon from '../../Icon';


var Option = function Option(props) {
  var _cx;

  var children = props.children,
      className = props.className,
      data = props.data,
      value = props.value,
      selected = props.selected,
      active = props.active,
      other = _objectWithoutProperties(props, ["children", "className", "data", "value", "selected", "active"]);

  var classNames = cx("".concat("waui", "-select__option"), (_cx = {}, _defineProperty(_cx, "".concat("waui", "-select__option_active"), active), _defineProperty(_cx, "".concat("waui", "-select__option_selected"), selected), _cx), className);
  return (/*#__PURE__*/React.createElement("li", _extends({
      className: classNames
    }, other), /*#__PURE__*/React.createElement(TextOverflow, null, /*#__PURE__*/React.createElement("div", null, children)), selected && /*#__PURE__*/React.createElement(Icon, {
      type: "check",
      className: "".concat("waui", "-select__option-icon_selected")
    }))
  );
};

Option.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  data: PropTypes.object,

  /** 值，与 Select value 对应，数据类型也要一致 */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  selected: PropTypes.bool,
  active: PropTypes.bool
};
export default Option;
